@@ -1,5 +1,7 @@
 /*------------------------------------------------------------------------------
 
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
+
    Copyright (c) 2004 
    LS Informationstechnik (LIKE)
    University of Erlangen Nuremberg
@@ -8,9 +10,9 @@
    Tyrell DarkIce
 
    File     : AlsaDspSource.h
-   Version  : $Revision: 1.2 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/AlsaDspSource.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -65,7 +67,7 @@
  *  An audio input based on the ALSA sound system 
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.2 $
+ *  @version $Revision: 394 $
  */
 class AlsaDspSource : public AudioSource, public virtual Reporter
 {
@@ -295,18 +297,3 @@ class AlsaDspSource : public AudioSource, public virtual Reporter
 
 #endif  /* ALSA_SOURCE_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/AlsaDspSource.h,v $
-
-  $Log: AlsaDspSource.h,v $
-  Revision 1.2  2005/04/14 11:53:17  darkeye
-  fixed API documentation issues
-
-  Revision 1.1  2004/02/15 12:06:29  darkeye
-  added ALSA support, thanks to Christian Forster
-
-  
-------------------------------------------------------------------------------*/
-
