@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : DarkIce.cpp
-   Version  : $Revision: 410 $
+   Version  : $Revision: 424 $
    Author   : $Author: darkeye $
    Location : $HeadURL$
    
@@ -105,7 +105,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: DarkIce.cpp 410 2007-04-26 08:22:45Z darkeye $";
+static const char fileid[] = "$Id: DarkIce.cpp 424 2008-07-07 14:33:34Z darkeye $";
 
 
 /*------------------------------------------------------------------------------
@@ -139,6 +139,7 @@ DarkIce :: init ( const Config      & config )              throw ( Exception )
     unsigned int             channel;
     bool                     reconnect;
     const char             * device;
+    const char             * jackClientName;
 
     // the [general] section
     if ( !(cs = config.get( "general")) ) {
@@ -172,8 +173,10 @@ DarkIce :: init ( const Config      & config )              throw ( Exception )
     str           = cs->getForSure( "channel", " missing in section [input]");
     channel       = Util::strToL( str);
     device        = cs->getForSure( "device", " missing in section [input]");
+    jackClientName = cs->get ( "jackClientName");
 
     dsp             = AudioSource::createDspSource( device,
+                                                    jackClientName,
                                                     sampleRate,
                                                     bitsPerSample,
                                                     channel );
@@ -362,26 +365,26 @@ DarkIce :: configIceCast (  const Config      & config,
 
 #ifdef HAVE_LAME_LIB
         if ( Util::strEq( str, "mp3") ) {
-			audioOuts[u].encoder = new LameLibEncoder( audioOuts[u].server.get(),
-													   dsp.get(),
-													   bitrateMode,
-													   bitrate,
-													   quality,
-													   sampleRate,
-													   channel,
-													   lowpass,
-													   highpass );
+            audioOuts[u].encoder = new LameLibEncoder( audioOuts[u].server.get(),
+                                                       dsp.get(),
+                                                       bitrateMode,
+                                                       bitrate,
+                                                       quality,
+                                                       sampleRate,
+                                                       channel,
+                                                       lowpass,
+                                                       highpass );
         }
 #endif
 #ifdef HAVE_TWOLAME_LIB
         if ( Util::strEq( str, "mp2") ) {
-			audioOuts[u].encoder = new TwoLameLibEncoder(
+            audioOuts[u].encoder = new TwoLameLibEncoder(
                                                       audioOuts[u].server.get(),
-													  dsp.get(),
-													  bitrateMode,
-													  bitrate,
-													  sampleRate,
-													  channel );
+                                                      dsp.get(),
+                                                      bitrateMode,
+                                                      bitrate,
+                                                      sampleRate,
+                                                      channel );
         }
 #endif
 
@@ -697,6 +700,7 @@ DarkIce :: configShoutCast (    const Config      & config,
         const char                * url             = 0;
         const char                * genre           = 0;
         bool                        isPublic        = false;
+        const char                * mountPoint      = 0;
         int                         lowpass         = 0;
         int                         highpass        = 0;
         const char                * irc             = 0;
@@ -755,6 +759,7 @@ DarkIce :: configShoutCast (    const Config      & config,
         port        = Util::strToL( str);
         password    = cs->getForSure("password"," missing in section ",stream);
         name        = cs->get( "name");
+        mountPoint  = cs->get( "mountPoint" );
         url         = cs->get( "url");
         genre       = cs->get( "genre");
         str         = cs->get( "public");
@@ -803,6 +808,7 @@ DarkIce :: configShoutCast (    const Config      & config,
         audioOuts[u].socket = new TcpSocket( server, port);
         audioOuts[u].server = new ShoutCast( audioOuts[u].socket.get(),
                                              password,
+                                             mountPoint,
                                              bitrate,
                                              name,
                                              url,
