@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2005 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : FaacEncoder.h
-   Version  : $Revision: 1.3 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/FaacEncoder.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -66,7 +66,7 @@
  *  A class representing faac AAC encoder.
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.3 $
+ *  @version $Revision: 394 $
  */
 class FaacEncoder : public AudioEncoder, public virtual Reporter
 {
@@ -98,15 +98,9 @@ class FaacEncoder : public AudioEncoder, public virtual Reporter
          */
         int                             lowpass;
 
-        /**
-         *  The Sink to dump mp3 data to
-         */
-        Ref<Sink>                   sink;
-
         /**
          *  Initialize the object.
          *
-         *  @param sink the sink to send mp3 output to
          *  @param lowpass frequency threshold for the lowpass filter.
          *                 Input above this frequency is cut.
          *                 If 0, faac's default values are used,
@@ -114,11 +108,9 @@ class FaacEncoder : public AudioEncoder, public virtual Reporter
          *  @exception Exception
          */
         inline void
-        init ( Sink           * sink,
-               int              lowpass)                throw (Exception)
+        init ( int              lowpass)                throw (Exception)
         {
             this->faacOpen        = false;
-            this->sink            = sink;
             this->lowpass         = lowpass;
 
             if ( getInBitsPerSample() != 16 && getInBitsPerSample() != 8 ) {
@@ -205,7 +197,8 @@ class FaacEncoder : public AudioEncoder, public virtual Reporter
                         int             lowpass       = 0)
                                                         throw ( Exception )
             
-                    : AudioEncoder ( inSampleRate,
+                    : AudioEncoder ( sink,
+                                     inSampleRate,
                                      inBitsPerSample,
                                      inChannel,
                                      inBigEndian,
@@ -215,7 +208,7 @@ class FaacEncoder : public AudioEncoder, public virtual Reporter
                                      outSampleRate,
                                      outChannel )
         {
-            init( sink, lowpass);
+            init( lowpass);
         }
 
         /**
@@ -248,14 +241,15 @@ class FaacEncoder : public AudioEncoder, public virtual Reporter
                         int                     lowpass       = 0)
                                                             throw ( Exception )
             
-                    : AudioEncoder ( as,
+                    : AudioEncoder ( sink,
+                                     as,
                                      outBitrateMode,
                                      outBitrate,
                                      outQuality,
                                      outSampleRate,
                                      outChannel )
         {
-            init( sink, lowpass);
+            init( lowpass);
         }
 
         /**
@@ -268,7 +262,7 @@ class FaacEncoder : public AudioEncoder, public virtual Reporter
                                                             throw ( Exception )
                     : AudioEncoder( encoder )
         {
-            init( encoder.sink.get(), encoder.lowpass);
+            init( encoder.lowpass);
         }
          
 
@@ -299,7 +293,7 @@ class FaacEncoder : public AudioEncoder, public virtual Reporter
             if ( this != &encoder ) {
                 strip();
                 AudioEncoder::operator=( encoder);
-                init( encoder.sink.get(), encoder.lowpass);
+                init( encoder.lowpass);
             }
 
             return *this;
@@ -437,22 +431,3 @@ class FaacEncoder : public AudioEncoder, public virtual Reporter
 
 #endif  /* AAC_ENCODER_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/FaacEncoder.h,v $
-
-  $Log: FaacEncoder.h,v $
-  Revision 1.3  2006/01/27 08:51:23  darkeye
-  fixed issue of double colons at the end of the declaration
-
-  Revision 1.2  2005/04/16 22:19:20  darkeye
-  changed remaining typos
-
-  Revision 1.1  2005/04/16 21:57:34  darkeye
-  added AAC support through the faac codec, http://www.audiocoding.com/
-
-
-  
-------------------------------------------------------------------------------*/
-
