@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : SolarisDspSource.h
-   Version  : $Revision: 1.5 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/SolarisDspSource.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -52,7 +52,7 @@
  *  An audio input based on Solaris /dev/audio devices
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.5 $
+ *  @version $Revision: 394 $
  */
 class SolarisDspSource : public AudioSource, public virtual Reporter
 {
@@ -255,27 +255,3 @@ class SolarisDspSource : public AudioSource, public virtual Reporter
 
 #endif  /* SOLARIS_DSP_SOURCE_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/SolarisDspSource.h,v $
-
-  $Log: SolarisDspSource.h,v $
-  Revision 1.5  2005/04/14 11:53:17  darkeye
-  fixed API documentation issues
-
-  Revision 1.4  2004/02/19 06:47:06  darkeye
-  finalized OpenBSD port
-
-  Revision 1.3  2004/02/18 21:08:11  darkeye
-  ported to OpenBSD (real-time scheduling not yet supported)
-
-  Revision 1.2  2001/09/18 14:57:19  darkeye
-  finalized Solaris port
-
-  Revision 1.1  2001/09/11 15:05:21  darkeye
-  added Solaris support
-
-  
-------------------------------------------------------------------------------*/
-
