@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : Util.cpp
-   Version  : $Revision: 1.13 $
+   Version  : $Revision: 399 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/Util.cpp,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -63,6 +63,24 @@
 #error need time.h
 #endif
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#else
+#error need unistd.h
+#endif
+
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#else
+#error need sys/time.h
+#endif
+
+#ifdef HAVE_SIGNAL_H
+#include <signal.h>
+#else
+#error need signal.h
+#endif
+
 
 #include "Util.h"
 
@@ -75,7 +93,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: Util.cpp,v 1.13 2004/02/15 12:06:30 darkeye Exp $";
+static const char fileid[] = "$Id: Util.cpp 399 2007-02-25 16:38:33Z darkeye $";
 
 
 /* ===============================================  local function prototypes */
@@ -267,25 +285,27 @@ Util :: strToD( const char    * str )                   throw ( Exception )
     return val;
 }
 
+
 /*------------------------------------------------------------------------------
  *  add current date to a file name, before the file extension (if any)
  *----------------------------------------------------------------------------*/
-char * 
-Util :: fileAddDate ( const char * str )                    throw ( Exception )
+char *
+Util :: fileAddDate ( const char * str,
+                      const char * format )             throw ( Exception )
 {
     unsigned int    size;
     char          * s;
     char          * strdate;
     char          * last;
     time_t          now;
-    
+
     if ( !str ) {
         throw Exception( __FILE__, __LINE__, "no str");
     }
 
     strdate = new char[128];
     now     = time(NULL);    
-    strftime( strdate, 128, "[%m-%d-%Y-%H-%M-%S]", localtime (&now));
+    strftime( strdate, 128, format, localtime (&now));
 
     // search for the part before the extension of the file name
     if ( !(last = strrchr( str, '.')) ) {
@@ -488,51 +508,22 @@ Util :: conv16 (    unsigned char     * pcmBuffer,
 }
 
 
-
 /*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/Util.cpp,v $
+ *  Make a thread sleep for a specified amount of time.
+ *----------------------------------------------------------------------------*/
+void
+Util :: sleep   (   long            sec,
+                    long            nsec)
+{
+    struct timespec     timespec;
+    sigset_t            sigset;
 
-  $Log: Util.cpp,v $
-  Revision 1.13  2004/02/15 12:06:30  darkeye
-  added ALSA support, thanks to Christian Forster
+    timespec.tv_sec  = sec;
+    timespec.tv_nsec = nsec;
 
-  Revision 1.12  2003/02/09 12:57:36  darkeye
-  cosmetic changes to the fileAddDate option
-
-  Revision 1.11  2002/12/22 01:20:32  darkeye
-  time.h include file was missing
-
-  Revision 1.10  2002/11/20 16:52:07  wandereq
-  added fileAddDate function
-
-  Revision 1.9  2002/08/20 18:39:14  darkeye
-  added HTTP Basic authentication for icecast2 logins
-
-  Revision 1.8  2002/07/21 08:47:06  darkeye
-  some exception cleanup (throw clauses in function declarations)
-
-  Revision 1.7  2002/03/28 16:45:46  darkeye
-  added functions strToD(), conv8(), conv16() and conv()
-
-  Revision 1.6  2001/08/30 17:25:56  darkeye
-  renamed configure.h to config.h
-
-  Revision 1.5  2000/11/12 13:31:40  darkeye
-  added kdoc-style documentation comments
-
-  Revision 1.4  2000/11/09 22:04:33  darkeye
-  added functions strLen strCpy and strCat
-
-  Revision 1.3  2000/11/09 06:44:21  darkeye
-  added strEq and strToL functions
-
-  Revision 1.2  2000/11/05 14:08:28  darkeye
-  changed builting to an automake / autoconf environment
-
-  Revision 1.1.1.1  2000/11/05 10:05:55  darkeye
-  initial version
-
-  
-------------------------------------------------------------------------------*/
+    // mask out SIGUSR1, as we're expecting that signal for other reasons
+    sigemptyset(&sigset);
+    sigaddset(&sigset, SIGUSR1);
 
+    pselect( 0, NULL, NULL, NULL, &timespec, &sigset);
+}
